GlabTop2-py
===========

GlabTop2-py is a Python package that calculates the ice-thickness distribution for
all glaciers in the model domain. GlabTop2-py uses Python 3.6 and PCRaster functionalities. GlabTop2-py is entirely based on the
GlabTop2 concepts as described by `Frey et al., 2014 <https://www.the-cryosphere.net/8/2313/2014/tc-8-2313-2014.pdf>`_.

Documentation
-------------

Reference documentation can be found `here <https://glabtop2-py.readthedocs.io/en/latest/>`_.

Installation
------------

GlabTop2-py can be installed via pip::

   pip install GlabTop2-py
   
   
Run GlabTop2-py
---------------

After installation via pip, the tool can be executed by::

   python -m GlabTop2.main -i config.cfg   
   
Copyright
---------
   
Copyright (C) 2018 Wilco Terink. GlabTop2-py is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with this program. If not, see `http://www.gnu.org/licenses/ <http://www.gnu.org/licenses/>`__.      